function StabilityDomain

% Set the extrapolation sequence
n = 1:5;

% Build the grid using meshgrid
[X, Y] = meshgrid(-5:0.1:5);

% Generate complex mesh
Z = X + 1i*Y;
  
% Evaluate the stability function S on each point of the complex mesh
Sz = zeros(size(Z));
for ii = 1:length(Z)
    for jj = 1:length(Z)
        Sz(ii, jj) = StabilityEval(Z(ii, jj), n);
    end
end
 
% Plotting
figure;
% call contourf() with contour lines abs(S) = [0 1 2 5] here:
[~, h] = contourf(X, Y, abs(Sz), [0 1 2 5]);
set(h,'ShowText','on','TextStep',get(h,'LevelStep'));
colormap(autumn);
colorbar

title('Stability domain of the extrapolated explicit Euler');
xlabel('Re');
ylabel('Im');
axis square;
grid on;

print -depsc StabilityDomain
end
